@@ -27,10 +27,16 @@
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
-#endif /* HAVE_CONFIG_H */
+#endif /* defined(HAVE_CONFIG_H) */
 
-void test_ngtcp2_vec_split(void);
-void test_ngtcp2_vec_merge(void);
-void test_ngtcp2_vec_len_varint(void);
+#define MUNIT_ENABLE_ASSERT_ALIASES
 
-#endif /* NGTCP2_VEC_TEST_H */
+#include "munit.h"
+
+extern const MunitSuite vec_suite;
+
+munit_void_test_decl(test_ngtcp2_vec_split)
+munit_void_test_decl(test_ngtcp2_vec_merge)
+munit_void_test_decl(test_ngtcp2_vec_len_varint)
+
+#endif /* !defined(NGTCP2_VEC_TEST_H) */
